@@ -19,7 +19,9 @@
 #' @param e0 A vector of target life expectancy, one element for each predicted time point. 
 #' @param mx0 A vector with starting age-specific mortality rates. In case of \code{modpmd} it can be 
 #'     a matrix where rows correspond to age groups
-#'     and columns correspond to time periods. Rownames define the starting ages of the age groups.
+#'     and columns correspond to time periods. Row names define the starting ages of the age groups. 
+#'     As the \eqn{\rho_x} coefficients are only available up to age 100, the \code{mx0} gets truncated 
+#'     if it contains values beyond 100. In such a case, a warning is issued.
 #' @param sex Either "male" or "female".
 #' @param nx Size of age groups. Should be either 5 or 1.
 #' @param interp.rho Logical controlling if the \eqn{\rho} coefficients should be interpolated 
@@ -33,14 +35,14 @@
 #' @return Function \code{pmd} and \code{modpmd} return a list with the following elements: a matrix \code{mx}
 #'     with the predicted mortality rates. If \code{keep.lt} is \code{TRUE}, it also 
 #'     contains matrices \code{sr} (survival rates), and life table quantities \code{Lx} and \code{lx}.
-#'     If \code{keep.rho} is \code{TRUE}, it contains a matrix \code{rho} where columns correpond 
+#'     If \code{keep.rho} is \code{TRUE}, it contains a matrix \code{rho} where columns correspond 
 #'     to the values in the \code{e0} vector and rows correspond to age groups.
 #' @export
 #' 
 #' @seealso \code{\link{mortcast}}, \code{\link{mortcast.blend}}, \code{\link{PMDrho}}
 #' @references
 #' Andreev, K., Gu, D., Gerland, P. (2013). Age Patterns of Mortality Improvement by Level of Life Expectancy at Birth with Applications to Mortality Projections. Paper presented at the Annual Meeting
-#' of the Population Association of America, New Orleans, LA. \url{https://paa2013.princeton.edu/papers/132554}.
+#' of the Population Association of America, New Orleans, LA. \url{https://paa2013.populationassociation.org/papers/132554}.
 #' 
 #' Gu, D., Pelletier, F., Sawyer, C. (2017). Projecting Age-sex-specific Mortality: A Comparison of the Modified Lee-Carter and Pattern of Mortality Decline Methods, UN Population Division, 
 #' Technical Paper No. 6. New York: United Nations. \url{https://population.un.org/wpp/Publications/Files/WPP2017_TechnicalPaperNo6.pdf}
@@ -195,6 +197,14 @@ modpmd <- function(e0, mx0, sex = c("male", "female"), nx = 5, interp.rho = FALS
     if(!nx %in% c(1, 5))
         stop("The nx argument must be either 5 or 1.")
     nage <- length(mx0l[[1]])
+    nage.rho <- sum(!is.na(rho[,1]))
+    if(nage.rho < nage){
+        for(i in 1:length(mx0l))
+            mx0l[[i]] <- mx0l[[i]][1:nage.rho]
+        rho <- rho[1:nage.rho,]
+        warning("The rho coefficients not available for all mx ages. mx will be truncated.")
+        nage <- nage.rho
+    }
     if(nx == 5) {
         default.ages <- c(0, 1, seq(5, length = nage - 2, by = 5))
         resnage <-  nage-1 # number of age groups of the resulting matrices 
@@ -614,7 +624,7 @@ logquadj <- function(e0m, e0f, ...) {
 #'     \code{min.age.groups} age categories, the coherent Kannisto method (\code{\link{cokannisto}}) 
 #'     is applied to extend the age groups into old ages.
 #' @param min.age.groups Minimum number of age groups. Triggers the application of Kannisto, see above. 
-#'     Change the default value if 1-year age groups are used (see Example).
+#'     For a 5-year age groups, the default is 28; for 1-year ages it is 131.
 #' @param match.e0 Logical. If \code{TRUE} the blended mx is scaled so that it matches the input e0.
 #' @param keep.lt Logical. If \code{TRUE} additional life table columns are kept in the 
 #'     resulting object. Only used if \code{match.e0} is \code{TRUE}.
@@ -701,7 +711,7 @@ logquadj <- function(e0m, e0f, ...) {
 #' @name mortcast.blend
 mortcast.blend <- function(e0m, e0f, 
                           meth1 = "lc", meth2 = "mlt", weights = c(1, 0.5), nx = 5, 
-                          apply.kannisto = TRUE, min.age.groups = 28, 
+                          apply.kannisto = TRUE, min.age.groups = if(nx == 5) 28 else 131, 
                           match.e0 = TRUE, keep.lt = FALSE, 
                           meth1.args = NULL, meth2.args = NULL, kannisto.args = NULL, ...) {
     get.a0rule <- function(a0rule = c("ak", "cd"), ...)
@@ -733,6 +743,9 @@ mortcast.blend <- function(e0m, e0f,
     mx2 <- do.call(methods.allowed[[meth2]], c(list(e0m, e0f), meth2.args))
     
     if(apply.kannisto) {
+        if(is.null(kannisto.args) && nx == 1){
+            kannisto.args <- list(est.ages = 90:99, proj.ages = 100:130)
+        }
         mx1 <- .apply.kannisto.if.needed(mx1, min.age.groups, kannisto.args)
         mx2 <- .apply.kannisto.if.needed(mx2, min.age.groups, kannisto.args)
     }
@@ -744,6 +757,12 @@ mortcast.blend <- function(e0m, e0f,
     res <- list()
     for(sex in names(mx1)) {
         if(! sex %in% names(mx2)) next
+        if(nrow(mx1[[sex]]$mx) != nrow(mx2[[sex]]$mx)){ # truncate to match the mx datasets
+            warning("Mismatch in number of age groups of the two mx datasets. mx truncated to ", 
+                    min(nrow(mx1[[sex]]$mx), nrow(mx2[[sex]]$mx)))
+            if(nrow(mx1[[sex]]$mx) < nrow(mx2[[sex]]$mx)) mx2[[sex]]$mx <- mx2[[sex]]$mx[1:nrow(mx1[[sex]]$mx),]
+            else mx1[[sex]]$mx[1:nrow(mx2[[sex]]$mx),]
+        }
         if(is.null(wmat))
            wmat <- matrix(w, ncol = npred, nrow = nrow(mx1[[sex]]$mx), byrow = TRUE)
         res[[sex]] <- list(mx = wmat * mx1[[sex]]$mx + (1-wmat) * mx2[[sex]]$mx)
